@@ -1,6 +1,7 @@
 import sys
 
 from ssort._builtins import MODULE_BUILTINS
+from ssort._exceptions import ResolutionError
 from ssort._graphs import Graph
 from ssort._statements import (
     statement_bindings,
@@ -9,12 +10,6 @@ from ssort._statements import (
 )
 
 
-class ResolutionError(Exception):
-    def __init__(self, msg, *, unresolved):
-        super().__init__(msg)
-        self.unresolved = unresolved
-
-
 def statements_graph(statements):
     """
     Returns a dictionary mapping from statements to lists of other statements.
